==> crunch-scrunch-0.8.2-sources.jar: org/apache/crunch/scrunch/ScalaReflectDataFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.crunch.scrunch;

import org.apache.avro.Schema;
import org.apache.avro.reflect.ReflectData;
import org.apache.avro.reflect.ReflectDatumReader;
import org.apache.avro.reflect.ReflectDatumWriter;

import org.apache.crunch.types.avro.ReflectDataFactory;

/**
 * An implementation of the {@code ReflectDataFactory} class to work with Scala classes.
 */
public class ScalaReflectDataFactory extends ReflectDataFactory {

  @Override
  public ReflectData getReflectData() { return ScalaSafeReflectData.get(); }
  
  @Override
  public <T> ReflectDatumReader<T> getReader(Schema schema) {
    return new ScalaSafeReflectDatumReader<T>(schema);
  }
  
  public <T> ReflectDatumWriter<T> getWriter() {
    return new ScalaSafeReflectDatumWriter<T>();
  }
}

==> crunch-scrunch-0.10.0-sources.jar: org/apache/crunch/scrunch/ScalaReflectDataFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.crunch.scrunch;

import org.apache.avro.Schema;
import org.apache.avro.reflect.ReflectData;
import org.apache.avro.reflect.ReflectDatumReader;
import org.apache.avro.reflect.ReflectDatumWriter;

import org.apache.crunch.types.avro.ReaderWriterFactory;
import org.apache.crunch.types.avro.ReflectDataFactory;

/**
 * An implementation of the {@code ReflectDataFactory} class to work with Scala classes.
 */
public class ScalaReflectDataFactory implements ReaderWriterFactory {

  @Override
  public ReflectData getData() { return ScalaSafeReflectData.getInstance(); }
  
  @Override
  public <T> ReflectDatumReader<T> getReader(Schema schema) {
    return new ScalaSafeReflectDatumReader<T>(schema);
  }

  @Override
  public <T> ReflectDatumWriter<T> getWriter(Schema schema) {
    return new ScalaSafeReflectDatumWriter<T>(schema);
  }
}
